[Cmake-commits] CMake branch, next, updated. v2.8.7-2402-g314ef3f

2012-02-01 Thread Rolf Eike Beer
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  314ef3faeaba86af73c468b1393cc7724aa8434e (commit)
   via  44d007b6593eeea2c2c47a4431603ed08bc22280 (commit)
   via  b2215bdb26c3e1f376232e6ef974e6208bf681f6 (commit)
   via  7ac717c079c4b4132c9accb6c01ab94ddcaf45d7 (commit)
  from  25e5396b37b55da97d992f11754da5413c024226 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=314ef3faeaba86af73c468b1393cc7724aa8434e
commit 314ef3faeaba86af73c468b1393cc7724aa8434e
Merge: 25e5396 44d007b
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Wed Feb 1 12:17:31 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Wed Feb 1 12:17:31 2012 -0500

Merge topic 'check_include_files_output' into next

44d007b CheckIncludeFiles: fix status output
b2215bd KWSys Nightly Date Stamp
7ac717c KWSys Nightly Date Stamp


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=44d007b6593eeea2c2c47a4431603ed08bc22280
commit 44d007b6593eeea2c2c47a4431603ed08bc22280
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Wed Feb 1 18:14:52 2012 +0100
Commit: Rolf Eike Beer e...@sf-mail.de
CommitDate: Wed Feb 1 18:14:52 2012 +0100

CheckIncludeFiles: fix status output

CHECK_INCLUDE_FILES(foo.h HAVE_FOO_H) gave an output like:

  Looking for include files HAVE_FOO_H

After this change it does now what CHECK_INCLUDE_FILE() also does:

  Looking for include files foo.h

diff --git a/Modules/CheckIncludeFiles.cmake b/Modules/CheckIncludeFiles.cmake
index 75b5ca1..642d962 100644
--- a/Modules/CheckIncludeFiles.cmake
+++ b/Modules/CheckIncludeFiles.cmake
@@ -44,7 +44,7 @@ MACRO(CHECK_INCLUDE_FILES INCLUDE VARIABLE)
 CONFIGURE_FILE(${CMAKE_ROOT}/Modules/CMakeConfigurableFile.in
   
${CMAKE_BINARY_DIR}${CMAKE_FILES_DIRECTORY}/CMakeTmp/CheckIncludeFiles.c 
@ONLY IMMEDIATE)
 
-MESSAGE(STATUS Looking for include files ${VARIABLE})
+MESSAGE(STATUS Looking for include files ${INCLUDE})
 TRY_COMPILE(${VARIABLE}
   ${CMAKE_BINARY_DIR}
   ${CMAKE_BINARY_DIR}${CMAKE_FILES_DIRECTORY}/CMakeTmp/CheckIncludeFiles.c
@@ -54,15 +54,15 @@ MACRO(CHECK_INCLUDE_FILES INCLUDE VARIABLE)
   ${CHECK_INCLUDE_FILES_INCLUDE_DIRS}
   OUTPUT_VARIABLE OUTPUT)
 IF(${VARIABLE})
-  MESSAGE(STATUS Looking for include files ${VARIABLE} - found)
-  SET(${VARIABLE} 1 CACHE INTERNAL Have include ${VARIABLE})
+  MESSAGE(STATUS Looking for include files ${INCLUDE} - found)
+  SET(${VARIABLE} 1 CACHE INTERNAL Have include ${INCLUDE})
   FILE(APPEND ${CMAKE_BINARY_DIR}${CMAKE_FILES_DIRECTORY}/CMakeOutput.log 
 Determining if files ${INCLUDE} 
 exist passed with the following output:\n
 ${OUTPUT}\n\n)
 ELSE(${VARIABLE})
-  MESSAGE(STATUS Looking for include files ${VARIABLE} - not found.)
-  SET(${VARIABLE}  CACHE INTERNAL Have includes ${VARIABLE})
+  MESSAGE(STATUS Looking for include files ${INCLUDE} - not found.)
+  SET(${VARIABLE}  CACHE INTERNAL Have includes ${INCLUDE})
   FILE(APPEND ${CMAKE_BINARY_DIR}${CMAKE_FILES_DIRECTORY}/CMakeError.log 
 Determining if files ${INCLUDE} 
 exist failed with the following output:\n

---

Summary of changes:
 Modules/CheckIncludeFiles.cmake   |   10 +-
 Source/kwsys/kwsysDateStamp.cmake |4 ++--
 2 files changed, 7 insertions(+), 7 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v2.8.7-2404-gea92423

2012-02-01 Thread Rolf Eike Beer
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  ea9242399868cc325739ce9e1bea9a0c3f0d85dc (commit)
   via  7d3c2afb3ae0f1cddc16e482edbe6069c39234ce (commit)
  from  314ef3faeaba86af73c468b1393cc7724aa8434e (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=ea9242399868cc325739ce9e1bea9a0c3f0d85dc
commit ea9242399868cc325739ce9e1bea9a0c3f0d85dc
Merge: 314ef3f 7d3c2af
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Wed Feb 1 13:30:59 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Wed Feb 1 13:30:59 2012 -0500

Merge topic 'perl-version' into next

7d3c2af FindPerlLibs: fix typo


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=7d3c2afb3ae0f1cddc16e482edbe6069c39234ce
commit 7d3c2afb3ae0f1cddc16e482edbe6069c39234ce
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Wed Feb 1 19:30:42 2012 +0100
Commit: Rolf Eike Beer e...@sf-mail.de
CommitDate: Wed Feb 1 19:30:42 2012 +0100

FindPerlLibs: fix typo

diff --git a/Modules/FindPerlLibs.cmake b/Modules/FindPerlLibs.cmake
index feeb6f2..0ac8060 100644
--- a/Modules/FindPerlLibs.cmake
+++ b/Modules/FindPerlLibs.cmake
@@ -255,7 +255,7 @@ set(PERL_INCLUDE_DIR  ${PERL_INCLUDE_PATH})
 set(PERL_INCLUDE_DIRS ${PERL_INCLUDE_PATH})
 set(PERL_LIBRARIES${PERL_LIBRARY})
 # For backward compatibility with CMake before 2.8.7
-set(PER_VERSION ${PERL_VERSION_STRING})
+set(PERL_VERSION ${PERL_VERSION_STRING})
 
 mark_as_advanced(
   PERL_INCLUDE_PATH

---

Summary of changes:
 Modules/FindPerlLibs.cmake |2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)


hooks/post-receive
diff --git a/Modules/FindPerlLibs.cmake b/Modules/FindPerlLibs.cmake
index eea55f1..0ac8060 100644
--- a/Modules/FindPerlLibs.cmake
+++ b/Modules/FindPerlLibs.cmake
@@ -55,19 +55,6 @@ if (PERL_EXECUTABLE)
 string(REGEX REPLACE prefix='([^']+)'.* \\1 PERL_PREFIX 
${PERL_PREFIX_OUTPUT_VARIABLE})
   endif (NOT PERL_PREFIX_RESULT_VARIABLE)
 
-  ### PERL_VERSION
-  execute_process(
-COMMAND
-  ${PERL_EXECUTABLE} -V:version
-  OUTPUT_VARIABLE
-PERL_VERSION_OUTPUT_VARIABLE
-  RESULT_VARIABLE
-PERL_VERSION_RESULT_VARIABLE
-  )
-  if (NOT PERL_VERSION_RESULT_VARIABLE)
-string(REGEX REPLACE version='([^']+)'.* \\1 PERL_VERSION 
${PERL_VERSION_OUTPUT_VARIABLE})
-  endif (NOT PERL_VERSION_RESULT_VARIABLE)
-
   ### PERL_ARCHNAME
   execute_process(
 COMMAND
@@ -206,19 +193,19 @@ if (PERL_EXECUTABLE)
   ### PERL_POSSIBLE_INCLUDE_PATHS
   

[Cmake-commits] CMake branch, master, updated. v2.8.7-220-gaa8aed8

2012-02-01 Thread David Cole
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  aa8aed83f25e71e938907a632608b300502f3b19 (commit)
   via  1562b9c0b918d31c3796084d8343b378c807d1c3 (commit)
  from  b2215bdb26c3e1f376232e6ef974e6208bf681f6 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=aa8aed83f25e71e938907a632608b300502f3b19
commit aa8aed83f25e71e938907a632608b300502f3b19
Merge: b2215bd 1562b9c
Author: David Cole david.c...@kitware.com
AuthorDate: Wed Feb 1 14:45:26 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Wed Feb 1 14:45:26 2012 -0500

Merge topic 'improve-findimagemagick'

1562b9c FindImageMagick: make use of more FPHSA features


---

Summary of changes:
 Modules/FindImageMagick.cmake |   52 +
 1 files changed, 42 insertions(+), 10 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.7-222-gbbc7259

2012-02-01 Thread David Cole
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  bbc7259f703566cef831b78d8616546bfe9c9d97 (commit)
   via  0051506aa4ea3e1fdbe5333b529a0a5af9476be5 (commit)
  from  aa8aed83f25e71e938907a632608b300502f3b19 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=bbc7259f703566cef831b78d8616546bfe9c9d97
commit bbc7259f703566cef831b78d8616546bfe9c9d97
Merge: aa8aed8 0051506
Author: David Cole david.c...@kitware.com
AuthorDate: Wed Feb 1 14:45:55 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Wed Feb 1 14:45:55 2012 -0500

Merge topic 'improve-findpng'

0051506 FindPNG: support version selection


---

Summary of changes:
 Modules/FindPNG.cmake |   11 ++-
 1 files changed, 10 insertions(+), 1 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.7-224-gb7fd024

2012-02-01 Thread David Cole
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  b7fd02422985cf4bf4e2ab2676b08fcbbf6ffdc9 (commit)
   via  409aeafa2518a1cd38709810ba765860ef21aeb8 (commit)
  from  bbc7259f703566cef831b78d8616546bfe9c9d97 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=b7fd02422985cf4bf4e2ab2676b08fcbbf6ffdc9
commit b7fd02422985cf4bf4e2ab2676b08fcbbf6ffdc9
Merge: bbc7259 409aeaf
Author: David Cole david.c...@kitware.com
AuthorDate: Wed Feb 1 14:46:15 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Wed Feb 1 14:46:15 2012 -0500

Merge topic 'findruby-no-dummy-version'

409aeaf FindRuby: do not blindly set version to 1.8.0


---

Summary of changes:
 Modules/FindRuby.cmake |   19 ++-
 1 files changed, 10 insertions(+), 9 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.7-226-ga98f99a

2012-02-01 Thread David Cole
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  a98f99a820cecae802d68400b2485706ae8d9e0b (commit)
   via  e01fe583b80208b1cd28f429cfac9c866453a994 (commit)
  from  b7fd02422985cf4bf4e2ab2676b08fcbbf6ffdc9 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=a98f99a820cecae802d68400b2485706ae8d9e0b
commit a98f99a820cecae802d68400b2485706ae8d9e0b
Merge: b7fd024 e01fe58
Author: David Cole david.c...@kitware.com
AuthorDate: Wed Feb 1 14:46:23 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Wed Feb 1 14:46:23 2012 -0500

Merge topic 'improve-findtclsh'

e01fe58 FindTclsh: support version selection


---

Summary of changes:
 Modules/FindTCL.cmake   |   12 
 Modules/FindTclsh.cmake |   12 +++-
 2 files changed, 19 insertions(+), 5 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.7-228-ga7c5a68

2012-02-01 Thread David Cole
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  a7c5a6896e440528bc4eafc4fc619539cb6323ce (commit)
   via  7d20619fbea357103f44ee219923d44922cf9641 (commit)
  from  a98f99a820cecae802d68400b2485706ae8d9e0b (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=a7c5a6896e440528bc4eafc4fc619539cb6323ce
commit a7c5a6896e440528bc4eafc4fc619539cb6323ce
Merge: a98f99a 7d20619
Author: David Cole david.c...@kitware.com
AuthorDate: Wed Feb 1 14:46:36 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Wed Feb 1 14:46:36 2012 -0500

Merge topic 'doc-IMPORTED-properties'

7d20619 Clarify IMPORTED_ target property documentation


---

Summary of changes:
 Source/cmTarget.cxx |   66 ++
 1 files changed, 29 insertions(+), 37 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.7-230-gc8d102e

2012-02-01 Thread David Cole
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  c8d102eb40f9a4d435538bde2254f79fb6d76354 (commit)
   via  1eaf1c9b0fae2142f8dca60f6b898afb74045058 (commit)
  from  a7c5a6896e440528bc4eafc4fc619539cb6323ce (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=c8d102eb40f9a4d435538bde2254f79fb6d76354
commit c8d102eb40f9a4d435538bde2254f79fb6d76354
Merge: a7c5a68 1eaf1c9
Author: David Cole david.c...@kitware.com
AuthorDate: Wed Feb 1 14:46:54 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Wed Feb 1 14:46:54 2012 -0500

Merge topic 'improve-selectlibraryconfigurations'

1eaf1c9 SelectLibraryConfigurations: do not output identical configurations


---

Summary of changes:
 Modules/SelectLibraryConfigurations.cmake |7 +++
 1 files changed, 3 insertions(+), 4 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.7-232-gfa6816b

2012-02-01 Thread David Cole
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  fa6816bd71bddcc6a018da062efe0a262edb74bd (commit)
   via  49b69add60d6fcd56688e276c3a4010759dade05 (commit)
  from  c8d102eb40f9a4d435538bde2254f79fb6d76354 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=fa6816bd71bddcc6a018da062efe0a262edb74bd
commit fa6816bd71bddcc6a018da062efe0a262edb74bd
Merge: c8d102e 49b69ad
Author: David Cole david.c...@kitware.com
AuthorDate: Wed Feb 1 14:47:15 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Wed Feb 1 14:47:15 2012 -0500

Merge topic 'improve-findlua51'

49b69ad FindLua51: add version support


---

Summary of changes:
 Modules/FindLua51.cmake |   14 --
 1 files changed, 12 insertions(+), 2 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.7-238-g9603ee9

2012-02-01 Thread David Cole
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  9603ee91154e222042118f5b056bc422c89b0abf (commit)
   via  9d7a00104f6efa4f13cf2a5c69c79b9d6f6e261d (commit)
  from  ba963564344d95e28ac2bcdf5a7d5147d1ab143a (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=9603ee91154e222042118f5b056bc422c89b0abf
commit 9603ee91154e222042118f5b056bc422c89b0abf
Merge: ba96356 9d7a001
Author: David Cole david.c...@kitware.com
AuthorDate: Wed Feb 1 14:48:47 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Wed Feb 1 14:48:47 2012 -0500

Merge topic 'improve-libxml2'

9d7a001 FindLibXml2: detect version when PkgConfig is not used


---

Summary of changes:
 Modules/FindLibXml2.cmake |   17 -
 1 files changed, 12 insertions(+), 5 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.7-240-g94af99d

2012-02-01 Thread David Cole
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  94af99d38813236bc381d2a8df2901fab09ea595 (commit)
   via  8e8db31f3395a2295668ab4cc39089e82b5421ef (commit)
  from  9603ee91154e222042118f5b056bc422c89b0abf (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=94af99d38813236bc381d2a8df2901fab09ea595
commit 94af99d38813236bc381d2a8df2901fab09ea595
Merge: 9603ee9 8e8db31
Author: David Cole david.c...@kitware.com
AuthorDate: Wed Feb 1 14:49:00 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Wed Feb 1 14:49:00 2012 -0500

Merge topic 'improve-findpostgresql'

8e8db31 FindPostgreSQL: support version selection


---

Summary of changes:
 Modules/FindPostgreSQL.cmake |   32 
 1 files changed, 16 insertions(+), 16 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.7-243-g3e0eeb9

2012-02-01 Thread David Cole
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  3e0eeb9fc832cde370ea70b1b3c8e7ebb42c860a (commit)
   via  f9c1c6225c4366918465b86e4c6976ecc266245f (commit)
   via  ca39c5cdd1ca28516791e00f213d6dee2179c6df (commit)
  from  94af99d38813236bc381d2a8df2901fab09ea595 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=3e0eeb9fc832cde370ea70b1b3c8e7ebb42c860a
commit 3e0eeb9fc832cde370ea70b1b3c8e7ebb42c860a
Merge: 94af99d f9c1c62
Author: David Cole david.c...@kitware.com
AuthorDate: Wed Feb 1 14:49:10 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Wed Feb 1 14:49:10 2012 -0500

Merge topic 'imported-target-visibility'

f9c1c62 Add test covering imported target scope rules
ca39c5c Optionally allow IMPORTED targets to be globally visible


---

Summary of changes:
 Source/cmAddExecutableCommand.cxx  |9 -
 Source/cmAddExecutableCommand.h|4 ++--
 Source/cmAddLibraryCommand.cxx |8 +++-
 Source/cmAddLibraryCommand.h   |5 +++--
 Source/cmGlobalGenerator.cxx   |   17 ++---
 Source/cmGlobalGenerator.h |3 ++-
 Source/cmMakefile.cxx  |9 +++--
 Source/cmMakefile.h|3 ++-
 Tests/CMakeOnly/CMakeLists.txt |2 ++
 Tests/CMakeOnly/TargetScope/CMakeLists.txt |   13 +
 Tests/CMakeOnly/TargetScope/Sib/CMakeLists.txt |6 ++
 Tests/CMakeOnly/TargetScope/Sub/CMakeLists.txt |9 +
 Tests/CMakeOnly/TargetScope/Sub/Sub/CMakeLists.txt |6 ++
 13 files changed, 81 insertions(+), 13 deletions(-)
 create mode 100644 Tests/CMakeOnly/TargetScope/CMakeLists.txt
 create mode 100644 Tests/CMakeOnly/TargetScope/Sib/CMakeLists.txt
 create mode 100644 Tests/CMakeOnly/TargetScope/Sub/CMakeLists.txt
 create mode 100644 Tests/CMakeOnly/TargetScope/Sub/Sub/CMakeLists.txt


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.7-245-ga3982c1

2012-02-01 Thread David Cole
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  a3982c15e48cb49f5f10f0c74dd0a9144f646d09 (commit)
   via  0bee3d95397497cb85a689d8f463b63858d50ebd (commit)
  from  3e0eeb9fc832cde370ea70b1b3c8e7ebb42c860a (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=a3982c15e48cb49f5f10f0c74dd0a9144f646d09
commit a3982c15e48cb49f5f10f0c74dd0a9144f646d09
Merge: 3e0eeb9 0bee3d9
Author: David Cole david.c...@kitware.com
AuthorDate: Wed Feb 1 14:49:21 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Wed Feb 1 14:49:21 2012 -0500

Merge topic 'fix-openssl-version'

0bee3d9 FindOpenSSL: properly parse the hex version components


---

Summary of changes:
 Modules/FindOpenSSL.cmake |   40 
 1 files changed, 36 insertions(+), 4 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.7-247-g79b7fe9

2012-02-01 Thread David Cole
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  79b7fe9d5e7be36b5c9ed5cf3178d4387cdd2ed1 (commit)
   via  3cc11c2f420ef7d30d96e238b24646d8c024641e (commit)
  from  a3982c15e48cb49f5f10f0c74dd0a9144f646d09 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=79b7fe9d5e7be36b5c9ed5cf3178d4387cdd2ed1
commit 79b7fe9d5e7be36b5c9ed5cf3178d4387cdd2ed1
Merge: a3982c1 3cc11c2
Author: David Cole david.c...@kitware.com
AuthorDate: Wed Feb 1 14:49:39 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Wed Feb 1 14:49:39 2012 -0500

Merge topic 'more-bison-version'

3cc11c2 FindBISON: add a version expression for GNU Bison 1.x


---

Summary of changes:
 Modules/FindBISON.cmake |5 +++--
 1 files changed, 3 insertions(+), 2 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.7-249-g29cddc6

2012-02-01 Thread David Cole
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  29cddc60cda2f1cf94f2753cfcca3c9c7e7959a5 (commit)
   via  bde7b5aafd5ab1ff180c900b0e473fc85bafa724 (commit)
  from  79b7fe9d5e7be36b5c9ed5cf3178d4387cdd2ed1 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=29cddc60cda2f1cf94f2753cfcca3c9c7e7959a5
commit 29cddc60cda2f1cf94f2753cfcca3c9c7e7959a5
Merge: 79b7fe9 bde7b5a
Author: David Cole david.c...@kitware.com
AuthorDate: Wed Feb 1 14:50:03 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Wed Feb 1 14:50:03 2012 -0500

Merge topic 'more-python-version'

bde7b5a FindPythonInterp: try harder to get a version number


---

Summary of changes:
 Modules/FindPythonInterp.cmake |   17 +++--
 1 files changed, 15 insertions(+), 2 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.7-251-g28088aa

2012-02-01 Thread David Cole
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  28088aa0454b5a0fdd1bf25e1cbf4e3f9dbc42ae (commit)
   via  00e30a0a34b8ac0972778e5f342a2445d9f05b41 (commit)
  from  29cddc60cda2f1cf94f2753cfcca3c9c7e7959a5 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=28088aa0454b5a0fdd1bf25e1cbf4e3f9dbc42ae
commit 28088aa0454b5a0fdd1bf25e1cbf4e3f9dbc42ae
Merge: 29cddc6 00e30a0
Author: David Cole david.c...@kitware.com
AuthorDate: Wed Feb 1 14:50:21 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Wed Feb 1 14:50:21 2012 -0500

Merge topic 'fix-jasper-debug'

00e30a0 FindJasper: fix library name


---

Summary of changes:
 Modules/FindJasper.cmake |2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.7-259-g0a11d33

2012-02-01 Thread David Cole
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  0a11d3306632a1368960c18cee9d9605ac78cc25 (commit)
   via  77e6c6fe844a0bcfd455da290a87adef5c1abd28 (commit)
  from  cf4c0f335d9e6c253e9c5953eceab9765fe8cc54 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=0a11d3306632a1368960c18cee9d9605ac78cc25
commit 0a11d3306632a1368960c18cee9d9605ac78cc25
Merge: cf4c0f3 77e6c6f
Author: David Cole david.c...@kitware.com
AuthorDate: Wed Feb 1 14:51:27 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Wed Feb 1 14:51:27 2012 -0500

Merge topic 'improve-findgettext'

77e6c6f FindGettext: support version selection


---

Summary of changes:
 Modules/FindGettext.cmake |   16 +++-
 1 files changed, 15 insertions(+), 1 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.7-261-ga4e0257

2012-02-01 Thread David Cole
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  a4e02578406c79c1ef0c43b72a1efabcb747d47b (commit)
   via  8de3b3d13ed40e97b74eeac4ce2d966a73c5168a (commit)
  from  0a11d3306632a1368960c18cee9d9605ac78cc25 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=a4e02578406c79c1ef0c43b72a1efabcb747d47b
commit a4e02578406c79c1ef0c43b72a1efabcb747d47b
Merge: 0a11d33 8de3b3d
Author: David Cole david.c...@kitware.com
AuthorDate: Wed Feb 1 14:51:36 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Wed Feb 1 14:51:36 2012 -0500

Merge topic 'check_cxx_compiler_flag_cmakeonly'

8de3b3d CheckCXXCompilerFlag test: make it a CMakeOnly test

diff --cc Tests/CMakeOnly/CMakeLists.txt
index 96b9972,2209b20..33c426a
--- a/Tests/CMakeOnly/CMakeLists.txt
+++ b/Tests/CMakeOnly/CMakeLists.txt
@@@ -15,6 -15,6 +15,8 @@@ add_CMakeOnly_test(CheckSymbolExists
  
  add_CMakeOnly_test(CheckCXXSymbolExists)
  
+ add_CMakeOnly_test(CheckCXXCompilerFlag)
+ 
  add_CMakeOnly_test(AllFindModules)
 +
 +add_CMakeOnly_test(TargetScope)

---

Summary of changes:
 Tests/CMakeLists.txt   |2 --
 Tests/CMakeOnly/CMakeLists.txt |2 ++
 .../CheckCXXCompilerFlag/CMakeLists.txt|   16 
 3 files changed, 2 insertions(+), 18 deletions(-)
 rename Tests/{Module = CMakeOnly}/CheckCXXCompilerFlag/CMakeLists.txt (86%)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.7-265-gbb29f27

2012-02-01 Thread David Cole
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  bb29f2765c0cd752c97862c6eb81975afdcdaed1 (commit)
   via  a94ef02c6e5d524a46f11d224b8b373545ea1534 (commit)
  from  46c7b7d85a69ff492414d92ba618ae1574e24e9a (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=bb29f2765c0cd752c97862c6eb81975afdcdaed1
commit bb29f2765c0cd752c97862c6eb81975afdcdaed1
Merge: 46c7b7d a94ef02
Author: David Cole david.c...@kitware.com
AuthorDate: Wed Feb 1 14:52:05 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Wed Feb 1 14:52:05 2012 -0500

Merge topic 'update-nightly-cmake-qt-version-again'

a94ef02 Update dashmacmini2 release script to use Qt 4.8.0


---

Summary of changes:
 Utilities/Release/dashmacmini2_release.cmake |2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v2.8.7-2435-g7177838

2012-02-01 Thread Eric Noulard
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  7177838d6b24218bed553764cfbf56886b7736a1 (commit)
   via  d34e9d19c657754a3edba49f1a7061d773b843c9 (commit)
   via  1819332e1f9b39f864e8a58c887c2ac8b4b9bcdd (commit)
   via  37f90ed57609308ff33223474567e5bfb94c2a21 (commit)
   via  7c82b7f51a7c7a02d060ca804e15049c0a745748 (commit)
  from  59d27a2e9d9204ded72d50a009ff2dd7e550182b (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=7177838d6b24218bed553764cfbf56886b7736a1
commit 7177838d6b24218bed553764cfbf56886b7736a1
Merge: 59d27a2 d34e9d1
Author: Eric Noulard eric.noul...@gmail.com
AuthorDate: Wed Feb 1 15:06:22 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Wed Feb 1 15:06:22 2012 -0500

Merge topic 'ImproveCPackDoc-reloaded' into next

d34e9d1 Merge branch 'ImproveCPackDoc-reloaded' of 
git://cmake.org/stage/cmake into ImproveCPackDoc-reloaded
1819332 Really avoid compiler warning about unused vars
37f90ed Calm down compiler warning about unused var
7c82b7f Fix potential bad memory access, thanks to Eike


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=d34e9d19c657754a3edba49f1a7061d773b843c9
commit d34e9d19c657754a3edba49f1a7061d773b843c9
Merge: 1819332 37f90ed
Author: Eric NOULARD eric.noul...@gmail.com
AuthorDate: Wed Feb 1 20:48:11 2012 +0100
Commit: Eric NOULARD eric.noul...@gmail.com
CommitDate: Wed Feb 1 20:48:11 2012 +0100

Merge branch 'ImproveCPackDoc-reloaded' of git://cmake.org/stage/cmake into 
ImproveCPackDoc-reloaded

diff --cc Source/CPack/cmCPackDocumentMacros.cxx
index ddc75a4,94d5391..050305f
--- a/Source/CPack/cmCPackDocumentMacros.cxx
+++ b/Source/CPack/cmCPackDocumentMacros.cxx
@@@ -1,8 -1,10 +1,10 @@@
  #include cmCPackDocumentMacros.h
  
  void cmCPackDocumentMacros::GetMacrosDocumentation(
 -std::vectorcmDocumentationEntry v)
 +std::vectorcmDocumentationEntry )
  {
+// avoid compiler warning
+(int)v.size();
 // Commented-out example of use
 //
 //cmDocumentationEntry e(cpack_macro,
diff --cc Source/CPack/cmCPackDocumentVariables.cxx
index 6327152,27d4df2..f90982f
--- a/Source/CPack/cmCPackDocumentVariables.cxx
+++ b/Source/CPack/cmCPackDocumentVariables.cxx
@@@ -1,8 -1,10 +1,10 @@@
  #include cmCPackDocumentVariables.h
  #include cmake.h
  
 -void cmCPackDocumentVariables::DefineVariables(cmake* cm)
 +void cmCPackDocumentVariables::DefineVariables(cmake* )
  {
+   // avoid compiler warning
+   (void*)cm;
// Subsection: variables defined/used by cpack,
// which are common to all CPack generators
  

http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=1819332e1f9b39f864e8a58c887c2ac8b4b9bcdd
commit 1819332e1f9b39f864e8a58c887c2ac8b4b9bcdd
Author: Eric NOULARD eric.noul...@gmail.com
AuthorDate: Wed Feb 1 20:47:28 2012 +0100
Commit: Eric NOULARD eric.noul...@gmail.com
CommitDate: Wed Feb 1 20:47:28 2012 +0100

Really avoid compiler warning about unused vars

diff --git a/Source/CPack/cmCPackDocumentMacros.cxx 
b/Source/CPack/cmCPackDocumentMacros.cxx
index 94d5391..ddc75a4 100644
--- a/Source/CPack/cmCPackDocumentMacros.cxx
+++ b/Source/CPack/cmCPackDocumentMacros.cxx
@@ -1,10 +1,8 @@
 #include cmCPackDocumentMacros.h
 
 void cmCPackDocumentMacros::GetMacrosDocumentation(
-std::vectorcmDocumentationEntry v)
+std::vectorcmDocumentationEntry )
 {
-   // avoid compiler warning
-   (int)v.size();
// Commented-out example of use
//
//cmDocumentationEntry e(cpack_macro,
diff --git a/Source/CPack/cmCPackDocumentVariables.cxx 
b/Source/CPack/cmCPackDocumentVariables.cxx
index 27d4df2..6327152 100644
--- a/Source/CPack/cmCPackDocumentVariables.cxx
+++ b/Source/CPack/cmCPackDocumentVariables.cxx
@@ -1,10 +1,8 @@
 #include cmCPackDocumentVariables.h
 #include cmake.h
 
-void cmCPackDocumentVariables::DefineVariables(cmake* cm)
+void cmCPackDocumentVariables::DefineVariables(cmake* )
 {
-  // avoid compiler warning
-  (void*)cm;
   // Subsection: variables defined/used by cpack,
   // which are common to all CPack generators
 

http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=37f90ed57609308ff33223474567e5bfb94c2a21
commit 37f90ed57609308ff33223474567e5bfb94c2a21
Author: Eric NOULARD eric.noul...@gmail.com
AuthorDate: Tue Jan 31 21:27:55 2012 +0100
Commit: Rolf Eike Beer e...@sf-mail.de
CommitDate: Tue Jan 31 22:45:07 2012 +0100

Calm down compiler warning about unused var

diff --git a/Source/CPack/cmCPackDocumentMacros.cxx 
b/Source/CPack/cmCPackDocumentMacros.cxx
index 8752e56..94d5391 100644
--- 

[Cmake-commits] CMake branch, next, updated. v2.8.7-2437-g0ffa193

2012-02-01 Thread Eric Noulard
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  0ffa193c6462c006a873a2cbfb2408ab2b718995 (commit)
   via  6364e8ab62ddfcdf9de7dd617ad7448551eb869d (commit)
  from  7177838d6b24218bed553764cfbf56886b7736a1 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=0ffa193c6462c006a873a2cbfb2408ab2b718995
commit 0ffa193c6462c006a873a2cbfb2408ab2b718995
Merge: 7177838 6364e8a
Author: Eric Noulard eric.noul...@gmail.com
AuthorDate: Wed Feb 1 15:09:25 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Wed Feb 1 15:09:25 2012 -0500

Merge topic 'ImproveCPackDoc-reloaded' into next

6364e8a Fix another compiler warning due to a typo


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=6364e8ab62ddfcdf9de7dd617ad7448551eb869d
commit 6364e8ab62ddfcdf9de7dd617ad7448551eb869d
Author: Eric NOULARD eric.noul...@gmail.com
AuthorDate: Wed Feb 1 21:07:29 2012 +0100
Commit: Eric NOULARD eric.noul...@gmail.com
CommitDate: Wed Feb 1 21:07:29 2012 +0100

Fix another compiler warning due to a typo

diff --git a/Source/cmDocumentation.h b/Source/cmDocumentation.h
index fae409f..83a0a09 100644
--- a/Source/cmDocumentation.h
+++ b/Source/cmDocumentation.h
@@ -156,7 +156,6 @@ public:
std::vectorcmDocumentationEntry commands,
cmake* cm,
const char *docSection);
-  ;
 private:
   void SetForm(Form f);
   void SetDocName(const char* docname);

---

Summary of changes:
 Source/cmDocumentation.h |1 -
 1 files changed, 0 insertions(+), 1 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v2.8.7-2441-g560b231

2012-02-01 Thread Rolf Eike Beer
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  560b231807cb6fb36925fe6fd74e393c3b9fd1fd (commit)
   via  9e25b127010464e7dea0f0f1989e5234ee4be536 (commit)
  from  8a26060c14ee93f00da71a266c5e2c25bcccedf3 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=560b231807cb6fb36925fe6fd74e393c3b9fd1fd
commit 560b231807cb6fb36925fe6fd74e393c3b9fd1fd
Merge: 8a26060 9e25b12
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Wed Feb 1 15:49:19 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Wed Feb 1 15:49:19 2012 -0500

Merge topic 'improve-libarchive' into next

9e25b12 FindLibArchive: support version selection


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=9e25b127010464e7dea0f0f1989e5234ee4be536
commit 9e25b127010464e7dea0f0f1989e5234ee4be536
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Wed Jan 25 17:42:00 2012 +0100
Commit: Rolf Eike Beer e...@sf-mail.de
CommitDate: Wed Feb 1 21:49:04 2012 +0100

FindLibArchive: support version selection

diff --git a/Modules/FindLibArchive.cmake b/Modules/FindLibArchive.cmake
index cedcd24..be931c5 100644
--- a/Modules/FindLibArchive.cmake
+++ b/Modules/FindLibArchive.cmake
@@ -54,8 +54,9 @@ endif()
 #  itself includes this FindLibArchive when built with an older CMake that does
 #  not provide it.  The older CMake also does not have CMAKE_CURRENT_LIST_DIR.)
 include(${CMAKE_ROOT}/Modules/FindPackageHandleStandardArgs.cmake)
-find_package_handle_standard_args(LibArchive DEFAULT_MSG
-  LibArchive_LIBRARY LibArchive_INCLUDE_DIR
+find_package_handle_standard_args(LibArchive
+  REQUIRED_VARS LibArchive_LIBRARY 
LibArchive_INCLUDE_DIR
+  VERSION_VAR LibArchive_VERSION
   )
 set(LibArchive_FOUND ${LIBARCHIVE_FOUND})
 unset(LIBARCHIVE_FOUND)

---

Summary of changes:


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v2.8.7-2443-g565d4c3

2012-02-01 Thread Eric Noulard
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  565d4c34e67f8bdb4b5730b05d835b63a0417e08 (commit)
   via  5d18851b25af4f363d72371a5a6492741436eb37 (commit)
  from  560b231807cb6fb36925fe6fd74e393c3b9fd1fd (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=565d4c34e67f8bdb4b5730b05d835b63a0417e08
commit 565d4c34e67f8bdb4b5730b05d835b63a0417e08
Merge: 560b231 5d18851
Author: Eric Noulard eric.noul...@gmail.com
AuthorDate: Wed Feb 1 17:36:42 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Wed Feb 1 17:36:42 2012 -0500

Merge topic 'AddTopLevelForComponent' into next

5d18851 CPackArchive restore default behavior and provide new variable.


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=5d18851b25af4f363d72371a5a6492741436eb37
commit 5d18851b25af4f363d72371a5a6492741436eb37
Author: Eric NOULARD eric.noul...@gmail.com
AuthorDate: Wed Feb 1 23:32:50 2012 +0100
Commit: Eric NOULARD eric.noul...@gmail.com
CommitDate: Wed Feb 1 23:32:50 2012 +0100

CPackArchive restore default behavior and provide new variable.

CPACK_COMPONENT_INCLUDE_TOPLEVEL_DIRECTORY should be set by the user
in order to get the toplevel directory included in the archive
whenever a componentized archive is requested. This solves bug #12129
and keeps fully backward compatible behavior.

diff --git a/Source/CPack/cmCPackArchiveGenerator.cxx 
b/Source/CPack/cmCPackArchiveGenerator.cxx
index 12d1796..0ff9050 100644
--- a/Source/CPack/cmCPackArchiveGenerator.cxx
+++ b/Source/CPack/cmCPackArchiveGenerator.cxx
@@ -58,7 +58,7 @@ int 
cmCPackArchiveGenerator::addOneComponentToArchive(cmArchiveWrite archive,
   // Change to local toplevel
   cmSystemTools::ChangeDirectory(localToplevel.c_str());
   std::string filePrefix;
-  if (this-IsOn(CPACK_INCLUDE_TOPLEVEL_DIRECTORY))
+  if (this-IsOn(CPACK_COMPONENT_INCLUDE_TOPLEVEL_DIRECTORY))
 {
 filePrefix = this-GetOption(CPACK_PACKAGE_FILE_NAME);
 filePrefix += /;
diff --git a/Source/CPack/cmCPackGenerator.cxx 
b/Source/CPack/cmCPackGenerator.cxx
index 01ed4df..f7d8a4d 100644
--- a/Source/CPack/cmCPackGenerator.cxx
+++ b/Source/CPack/cmCPackGenerator.cxx
@@ -691,7 +691,7 @@ int cmCPackGenerator::InstallProjectViaInstallCMakeProjects(
   //  one install directory for each component.
   tempInstallDirectory +=
 GetComponentInstallDirNameSuffix(installComponent);
-  if (this-IsOn(CPACK_INCLUDE_TOPLEVEL_DIRECTORY))
+  if (this-IsOn(CPACK_COMPONENT_INCLUDE_TOPLEVEL_DIRECTORY))
 {
 tempInstallDirectory += /;
 tempInstallDirectory += this-GetOption(CPACK_PACKAGE_FILE_NAME);

---

Summary of changes:
 Source/CPack/cmCPackArchiveGenerator.cxx |2 +-
 Source/CPack/cmCPackGenerator.cxx|2 +-
 2 files changed, 2 insertions(+), 2 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.7-266-ge858440

2012-02-01 Thread KWSys Robot
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  e8584401852a871b6cda57e570b7bb04b6dacf74 (commit)
  from  bb29f2765c0cd752c97862c6eb81975afdcdaed1 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=e8584401852a871b6cda57e570b7bb04b6dacf74
commit e8584401852a871b6cda57e570b7bb04b6dacf74
Author: KWSys Robot kwro...@kitware.com
AuthorDate: Thu Feb 2 00:05:06 2012 -0500
Commit: KWSys Robot kwro...@kitware.com
CommitDate: Thu Feb 2 00:05:06 2012 -0500

KWSys Nightly Date Stamp

diff --git a/Source/kwsys/kwsysDateStamp.cmake 
b/Source/kwsys/kwsysDateStamp.cmake
index b64fb43..664bf6f 100644
--- a/Source/kwsys/kwsysDateStamp.cmake
+++ b/Source/kwsys/kwsysDateStamp.cmake
@@ -18,4 +18,4 @@ SET(KWSYS_DATE_STAMP_YEAR  2012)
 SET(KWSYS_DATE_STAMP_MONTH 02)
 
 # KWSys version date day component.  Format is DD.
-SET(KWSYS_DATE_STAMP_DAY   01)
+SET(KWSYS_DATE_STAMP_DAY   02)

---

Summary of changes:
 Source/kwsys/kwsysDateStamp.cmake |2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v2.8.7-2392-gbacfff6

2012-02-01 Thread Rolf Eike Beer
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  bacfff625c54e1f9991f27480baef6e25681bc7d (commit)
   via  0b17c6909deafcb5f94527e267a94be7c6dcb9e7 (commit)
  from  8c2f3c7ebd6225afe5d08043924f3dbf09eea701 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=bacfff625c54e1f9991f27480baef6e25681bc7d
commit bacfff625c54e1f9991f27480baef6e25681bc7d
Merge: 8c2f3c7 0b17c69
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Wed Feb 1 12:09:19 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Wed Feb 1 12:09:19 2012 -0500

Merge topic 'AllFindModules-test' into next

0b17c69 AllFindModules test: check *_VERSION_STRING first


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=0b17c6909deafcb5f94527e267a94be7c6dcb9e7
commit 0b17c6909deafcb5f94527e267a94be7c6dcb9e7
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Wed Feb 1 18:09:07 2012 +0100
Commit: Rolf Eike Beer e...@sf-mail.de
CommitDate: Wed Feb 1 18:09:07 2012 +0100

AllFindModules test: check *_VERSION_STRING first

diff --git a/Tests/CMakeOnly/AllFindModules/CMakeLists.txt 
b/Tests/CMakeOnly/AllFindModules/CMakeLists.txt
index 468472b..127e9d7 100644
--- a/Tests/CMakeOnly/AllFindModules/CMakeLists.txt
+++ b/Tests/CMakeOnly/AllFindModules/CMakeLists.txt
@@ -53,14 +53,14 @@ set(VERSIONS_REQUIRED
 
 foreach(VTEST ${VERSIONS_REQUIRED})
 if (${VTEST}_FOUND)
-if (DEFINED ${VTEST}_VERSION)
-if (NOT ${VTEST}_VERSION MATCHES 
^[0-9][0-9\\.]*[A-Za-z_]*[0-9\\.]*$)
-message(SEND_ERROR ${VTEST}_VERSION has unexpected content 
${${VTEST}_VERSION})
-endif()
-elseif (DEFINED ${VTEST}_VERSION_STRING)
+if (DEFINED ${VTEST}_VERSION_STRING)
 if (NOT ${VTEST}_VERSION_STRING MATCHES 
^[0-9][0-9\\.]*[A-Za-z_]*[0-9\\.]*$)
 message(SEND_ERROR ${VTEST}_VERSION_STRING has unexpected 
content ${${VTEST}_VERSION_STRING})
 endif()
+elseif (DEFINED ${VTEST}_VERSION)
+if (NOT ${VTEST}_VERSION MATCHES 
^[0-9][0-9\\.]*[A-Za-z_]*[0-9\\.]*$)
+message(SEND_ERROR ${VTEST}_VERSION has unexpected content 
${${VTEST}_VERSION})
+endif()
 else()
 message(SEND_ERROR ${VTEST}_FOUND is set but no version number is 
defined)
 endif()

---

Summary of changes:
 Tests/CMakeOnly/AllFindModules/CMakeLists.txt |   10 +-
 1 files changed, 5 insertions(+), 5 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v2.8.7-2394-g170ef06

2012-02-01 Thread Rolf Eike Beer
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  170ef0621692eb8807c3e84b92b097e457953d6b (commit)
   via  c90890d648e4bd7fd2b85456351ae43ccbf04af3 (commit)
  from  bacfff625c54e1f9991f27480baef6e25681bc7d (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=170ef0621692eb8807c3e84b92b097e457953d6b
commit 170ef0621692eb8807c3e84b92b097e457953d6b
Merge: bacfff6 c90890d
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Wed Feb 1 12:11:06 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Wed Feb 1 12:11:06 2012 -0500

Merge topic 'perl-version' into next

c90890d FindPerlLibs: keep PERL_VERSION for compatibility


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=c90890d648e4bd7fd2b85456351ae43ccbf04af3
commit c90890d648e4bd7fd2b85456351ae43ccbf04af3
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Wed Feb 1 18:10:48 2012 +0100
Commit: Rolf Eike Beer e...@sf-mail.de
CommitDate: Wed Feb 1 18:10:48 2012 +0100

FindPerlLibs: keep PERL_VERSION for compatibility

diff --git a/Modules/FindPerlLibs.cmake b/Modules/FindPerlLibs.cmake
index e1db280..feeb6f2 100644
--- a/Modules/FindPerlLibs.cmake
+++ b/Modules/FindPerlLibs.cmake
@@ -254,6 +254,8 @@ find_package_handle_standard_args(PerlLibs REQUIRED_VARS 
PERL_LIBRARY PERL_INCLU
 set(PERL_INCLUDE_DIR  ${PERL_INCLUDE_PATH})
 set(PERL_INCLUDE_DIRS ${PERL_INCLUDE_PATH})
 set(PERL_LIBRARIES${PERL_LIBRARY})
+# For backward compatibility with CMake before 2.8.7
+set(PER_VERSION ${PERL_VERSION_STRING})
 
 mark_as_advanced(
   PERL_INCLUDE_PATH

---

Summary of changes:
 Modules/FindPerlLibs.cmake |2 ++
 1 files changed, 2 insertions(+), 0 deletions(-)


hooks/post-receive
diff --git a/Modules/FindPerlLibs.cmake b/Modules/FindPerlLibs.cmake
index eea55f1..feeb6f2 100644
--- a/Modules/FindPerlLibs.cmake
+++ b/Modules/FindPerlLibs.cmake
@@ -55,19 +55,6 @@ if (PERL_EXECUTABLE)
 string(REGEX REPLACE prefix='([^']+)'.* \\1 PERL_PREFIX 
${PERL_PREFIX_OUTPUT_VARIABLE})
   endif (NOT PERL_PREFIX_RESULT_VARIABLE)
 
-  ### PERL_VERSION
-  execute_process(
-COMMAND
-  ${PERL_EXECUTABLE} -V:version
-  OUTPUT_VARIABLE
-PERL_VERSION_OUTPUT_VARIABLE
-  RESULT_VARIABLE
-PERL_VERSION_RESULT_VARIABLE
-  )
-  if (NOT PERL_VERSION_RESULT_VARIABLE)
-string(REGEX REPLACE version='([^']+)'.* \\1 PERL_VERSION 
${PERL_VERSION_OUTPUT_VARIABLE})
-  endif (NOT PERL_VERSION_RESULT_VARIABLE)
-
   ### PERL_ARCHNAME
   execute_process(
 COMMAND
@@ -206,19 +193,19 @@ if (PERL_EXECUTABLE)
   ### PERL_POSSIBLE_INCLUDE_PATHS
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v2.8.7-2406-g5ceab52

2012-02-01 Thread Rolf Eike Beer
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  5ceab525fcf04600df3e9136274063914859472f (commit)
   via  31826b5166f0921d34625d86e82dd73fb47652d5 (commit)
  from  ea9242399868cc325739ce9e1bea9a0c3f0d85dc (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=5ceab525fcf04600df3e9136274063914859472f
commit 5ceab525fcf04600df3e9136274063914859472f
Merge: ea92423 31826b5
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Wed Feb 1 13:31:30 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Wed Feb 1 13:31:30 2012 -0500

Merge topic 'perl-version' into next

31826b5 FindPerl{,Libs}: move version detection into FindPerl


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=31826b5166f0921d34625d86e82dd73fb47652d5
commit 31826b5166f0921d34625d86e82dd73fb47652d5
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Wed Jan 18 18:08:43 2012 +0100
Commit: Rolf Eike Beer e...@sf-mail.de
CommitDate: Wed Feb 1 19:31:17 2012 +0100

FindPerl{,Libs}: move version detection into FindPerl

If the first attempt of getting the version doesn't succeed, try a second
approach.

diff --git a/Modules/FindPerl.cmake b/Modules/FindPerl.cmake
index db393e7..ae686df 100644
--- a/Modules/FindPerl.cmake
+++ b/Modules/FindPerl.cmake
@@ -1,8 +1,9 @@
 # - Find perl
 # this module looks for Perl
 #
 #  PERL_EXECUTABLE - the full path to perl
 #  PERL_FOUND  - If false, don't attempt to use perl.
 
 #=
 # Copyright 2001-2009 Kitware, Inc.
@@ -39,12 +40,44 @@ FIND_PROGRAM(PERL_EXECUTABLE
   PATHS ${PERL_POSSIBLE_BIN_PATHS}
   )
 
+IF(PERL_EXECUTABLE)
+  ### PERL_VERSION
+  EXECUTE_PROCESS(
+COMMAND
+  ${PERL_EXECUTABLE} -V:version
+  OUTPUT_VARIABLE
+PERL_VERSION_OUTPUT_VARIABLE
+  RESULT_VARIABLE
+PERL_VERSION_RESULT_VARIABLE
+  ERROR_QUIET
+  OUTPUT_STRIP_TRAILING_WHITESPACE
+  )
+  IF(NOT PERL_VERSION_RESULT_VARIABLE AND NOT PERL_VERSION_OUTPUT_VARIABLE 
MATCHES ^version='UNKNOWN')
+STRING(REGEX REPLACE version='([^']+)'.* \\1 PERL_VERSION_STRING 
${PERL_VERSION_OUTPUT_VARIABLE})
+  ELSE()
+EXECUTE_PROCESS(
+  COMMAND ${PERL_EXECUTABLE} -v
+  OUTPUT_VARIABLE PERL_VERSION_OUTPUT_VARIABLE
+  RESULT_VARIABLE PERL_VERSION_RESULT_VARIABLE
+  ERROR_QUIET
+  OUTPUT_STRIP_TRAILING_WHITESPACE
+)
+IF(NOT PERL_VERSION_RESULT_VARIABLE AND PERL_VERSION_OUTPUT_VARIABLE 
MATCHES This is perl.*[ \\(]v([0-9\\._]+)[ \\)])
+  STRING(REGEX REPLACE .*This is perl.*[ \\(]v([0-9\\._]+)[ \\)].* \\1 
PERL_VERSION_STRING ${PERL_VERSION_OUTPUT_VARIABLE})
+ELSEIF(NOT PERL_VERSION_RESULT_VARIABLE AND PERL_VERSION_OUTPUT_VARIABLE 
MATCHES This is perl, version ([0-9\\._]+) +)
+  STRING(REGEX REPLACE .*This is perl, version ([0-9\\._]+) +.* \\1 
PERL_VERSION_STRING ${PERL_VERSION_OUTPUT_VARIABLE})
+ENDIF()
+  ENDIF()
+ENDIF(PERL_EXECUTABLE)
+
 # Deprecated settings for compatibility with CMake1.4
 SET(PERL ${PERL_EXECUTABLE})
 
 # handle the QUIETLY and REQUIRED arguments and set PERL_FOUND to TRUE if 
 # all listed variables are TRUE
 INCLUDE(${CMAKE_CURRENT_LIST_DIR}/FindPackageHandleStandardArgs.cmake)
-FIND_PACKAGE_HANDLE_STANDARD_ARGS(Perl DEFAULT_MSG PERL_EXECUTABLE)
+FIND_PACKAGE_HANDLE_STANDARD_ARGS(Perl
+  REQUIRED_VARS PERL_EXECUTABLE
+  VERSION_VAR PERL_VERSION_STRING)
 
 MARK_AS_ADVANCED(PERL_EXECUTABLE)
@@ -1,8 +1,9 @@
 # this module looks for Perl
 #
-#  PERL_EXECUTABLE - the full path to perl
-#  PERL_FOUND  - If false, don't attempt to use perl.
+#  PERL_EXECUTABLE - the full path to perl
+#  PERL_FOUND  - If false, don't attempt to use perl.
+#  PERL_VERSION_STRING - version of perl found (since CMake 2.8.8)
 
 #=
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v2.8.7-2396-g28009fa

2012-02-01 Thread Rolf Eike Beer
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  28009fadac1ed04cb437fd6d13d33fe2ffa37aa0 (commit)
   via  a67eca85515f0fecb40aa836fff96ea34754125b (commit)
  from  170ef0621692eb8807c3e84b92b097e457953d6b (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=28009fadac1ed04cb437fd6d13d33fe2ffa37aa0
commit 28009fadac1ed04cb437fd6d13d33fe2ffa37aa0
Merge: 170ef06 a67eca8
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Wed Feb 1 12:12:00 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Wed Feb 1 12:12:00 2012 -0500

Merge topic 'perl-version' into next

a67eca8 FindPerl{,Libs}: move version detection into FindPerl


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=a67eca85515f0fecb40aa836fff96ea34754125b
commit a67eca85515f0fecb40aa836fff96ea34754125b
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Wed Jan 18 18:08:43 2012 +0100
Commit: Rolf Eike Beer e...@sf-mail.de
CommitDate: Wed Feb 1 18:11:33 2012 +0100

FindPerl{,Libs}: move version detection into FindPerl

If the first attempt of getting the version doesn't succeed, try a second
approach.

diff --git a/Modules/FindPerl.cmake b/Modules/FindPerl.cmake
index db393e7..ae686df 100644
--- a/Modules/FindPerl.cmake
+++ b/Modules/FindPerl.cmake
@@ -1,8 +1,9 @@
 # - Find perl
 # this module looks for Perl
 #
 #  PERL_EXECUTABLE - the full path to perl
 #  PERL_FOUND  - If false, don't attempt to use perl.
 
 #=
 # Copyright 2001-2009 Kitware, Inc.
@@ -39,12 +40,44 @@ FIND_PROGRAM(PERL_EXECUTABLE
   PATHS ${PERL_POSSIBLE_BIN_PATHS}
   )
 
+IF(PERL_EXECUTABLE)
+  ### PERL_VERSION
+  EXECUTE_PROCESS(
+COMMAND
+  ${PERL_EXECUTABLE} -V:version
+  OUTPUT_VARIABLE
+PERL_VERSION_OUTPUT_VARIABLE
+  RESULT_VARIABLE
+PERL_VERSION_RESULT_VARIABLE
+  ERROR_QUIET
+  OUTPUT_STRIP_TRAILING_WHITESPACE
+  )
+  IF(NOT PERL_VERSION_RESULT_VARIABLE AND NOT PERL_VERSION_OUTPUT_VARIABLE 
MATCHES ^version='UNKNOWN')
+STRING(REGEX REPLACE version='([^']+)'.* \\1 PERL_VERSION_STRING 
${PERL_VERSION_OUTPUT_VARIABLE})
+  ELSE()
+EXECUTE_PROCESS(
+  COMMAND ${PERL_EXECUTABLE} -v
+  OUTPUT_VARIABLE PERL_VERSION_OUTPUT_VARIABLE
+  RESULT_VARIABLE PERL_VERSION_RESULT_VARIABLE
+  ERROR_QUIET
+  OUTPUT_STRIP_TRAILING_WHITESPACE
+)
+IF(NOT PERL_VERSION_RESULT_VARIABLE AND PERL_VERSION_OUTPUT_VARIABLE 
MATCHES This is perl.*[ \\(]v([0-9\\._]+)[ \\)])
+  STRING(REGEX REPLACE .*This is perl.*[ \\(]v([0-9\\._]+)[ \\)].* \\1 
PERL_VERSION_STRING ${PERL_VERSION_OUTPUT_VARIABLE})
+ELSEIF(NOT PERL_VERSION_RESULT_VARIABLE AND PERL_VERSION_OUTPUT_VARIABLE 
MATCHES This is perl, version ([0-9\\._]+) +)
+  STRING(REGEX REPLACE .*This is perl, version ([0-9\\._]+) +.* \\1 
PERL_VERSION_STRING ${PERL_VERSION_OUTPUT_VARIABLE})
+ENDIF()
+  ENDIF()
+ENDIF(PERL_EXECUTABLE)
+
 # Deprecated settings for compatibility with CMake1.4
 SET(PERL ${PERL_EXECUTABLE})
 
 # handle the QUIETLY and REQUIRED arguments and set PERL_FOUND to TRUE if 
 # all listed variables are TRUE
 INCLUDE(${CMAKE_CURRENT_LIST_DIR}/FindPackageHandleStandardArgs.cmake)
-FIND_PACKAGE_HANDLE_STANDARD_ARGS(Perl DEFAULT_MSG PERL_EXECUTABLE)
+FIND_PACKAGE_HANDLE_STANDARD_ARGS(Perl
+  REQUIRED_VARS PERL_EXECUTABLE
+  VERSION_VAR PERL_VERSION_STRING)
 
 MARK_AS_ADVANCED(PERL_EXECUTABLE)
@@ -1,8 +1,9 @@
 # this module looks for Perl
 #
-#  PERL_EXECUTABLE - the full path to perl
-#  PERL_FOUND  - If false, don't attempt to use perl.
+#  PERL_EXECUTABLE - the full path to perl
+#  PERL_FOUND  - If false, don't attempt to use perl.
+#  PERL_VERSION_STRING - version of perl found (since CMake 2.8.8)
 
 #=